Saving the Novel to a readable format
=====================================

Commands to save the Novel to a readable format like EPUB.

.. click:: web_novel_scraper.__main__:save_novel_to_epub
    :prog: save-novel-to-epub
    :nested: full